@@ -10,7 +10,16 @@ if [ ! -b "$cdwriter" ] || [ ! -b "$cdreader" ] || [ $cdwriter == $cdreader ]; t
 fi
 
 
+if mount | grep -q "^$cdwriter "; then
+	umount $cdwriter || exit 255
+fi
+
 source simpleburn-burning-suite quiet
 
-tracksize=`isosize -d 1048576 $cdreader`
+tracksize=`simpleburn-media-detection $cdreader | grep "mediasize" | cut -f2 -d=`
+let tracksize=tracksize/1024
 $CDRECORD -v gracetime=3 dev=$cdwriter -isosize $cdreader | simpleburn-gauges cdrecord $tracksize
+status=${PIPESTATUS[0]}
+
+echo "100"
+exit $status
